Module dsl

Module dsl 

Re-exports all of the columns of this table, as well as the table struct renamed to the module name. This is meant to be glob imported for functions which only deal with one table.

Structs

attempt
completed_at
created_at
error_details
id
last_error
last_recovery_at
max_attempts
recovery_attempts
retry_at
started_at
status
sub_status
task_configuration
task_executions
The actual table struct
task_name
trigger_rules
updated_at
workflow_execution_id