Module workflow_executions

Module workflow_executions 

Modules

columns
Contains all of the columns of this table
dsl
Re-exports all of the columns of this table, as well as the table struct renamed to the module name. This is meant to be glob imported for functions which only deal with one table.

Structs

completed_at
context_id
created_at
error_details
id
last_recovery_at
pause_reason
paused_at
recovery_attempts
star
Represents table_name.*, which is sometimes needed for efficient count queries. It cannot be used in place of all_columns, and has a SqlType of () to prevent it being used that way
started_at
status
table
The actual table struct
updated_at
workflow_name
workflow_version

Constants

all_columns
A tuple of all of the columns on this table

Type Aliases

BoxedQuery
Helper type for representing a boxed query from this table
SqlType
The SQL type of all of the columns on this table