Modules
- columns
- Contains all of the columns of this table
- dsl
- Re-exports all of the columns of this table, as well as the table struct renamed to the module name. This is meant to be glob imported for functions which only deal with one table.
Structs
- completed_
at - context_
id - created_
at - error_
details - id
- last_
recovery_ at - pause_
reason - paused_
at - recovery_
attempts - star
- Represents
table_name.*, which is sometimes needed for efficient count queries. It cannot be used in place ofall_columns, and has aSqlTypeof()to prevent it being used that way - started_
at - status
- table
- The actual table struct
- updated_
at - workflow_
name - workflow_
version
Constants
- all_
columns - A tuple of all of the columns on this table
Type Aliases
- Boxed
Query - Helper type for representing a boxed query from this table
- SqlType
- The SQL type of all of the columns on this table